#
# spec file for package terraform-provider-openstack
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Make sure that the binary is not getting stripped.
%if 0%{?suse_version}
%{go_nostrip}
%endif

Name:           terraform-provider-openstack
Version:        1.28.0
Release:        bp153.1.62
Summary:        Terraform OpenStack provider
License:        MPL-2.0
Group:          System/Management
URL:            https://github.com/terraform-providers/terraform-provider-openstack
Source:         %{name}-%{version}.tar.xz
Source99:       terraform-provider-openstack-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?ubuntu_version}
BuildRequires:  debhelper
BuildRequires:  dh-golang
BuildRequires:  golang-go
BuildRequires:  libvirt-dev
BuildRequires:  pkg-config
BuildRequires:  xz-utils
%else
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  golang
%endif
%if 0%{?suse_version}
BuildRequires:  golang-packaging
BuildRequires:  xz
BuildRequires:  golang(API) >= 1.14
%endif
Requires:       mkisofs
Requires:       terraform >= 0.12.20
BuildRequires:  xz
%endif
%if 0%{?suse_version}
%{go_provides}
%endif

%description
This is a terraform provider that lets you provision servers on an OpenStack platform via Terraform.

%prep
%setup -q -n %{name}-%{version}

%build
export GO111MODULE=off
export GOPROXY=off
%if 0%{?suse_version}
%goprep github.com/terraform-providers/%{name}
%gobuild
%endif
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version} || 0%{?ubuntu_version}
mkdir -p ./_build/src/github.com/terraform-providers/
ln -s $(pwd) ./_build/src/github.com/terraform-providers/terraform-provider-openstack
export GOPATH=$(pwd)/_build
cd _build/src/github.com/terraform-providers/terraform-provider-openstack
go build .
%endif
ln -s %{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}_v%{version}

%install
export GO111MODULE=off
export GOPROXY=off
%if 0%{?suse_version}
%goinstall
rm -rf %{buildroot}/%{_libdir}/go/contrib
%endif
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version} || 0%{?ubuntu_version}
export GOPATH=$(pwd)/_build
mkdir -p %{buildroot}%{_bindir}
export GOBIN=%{buildroot}%{_bindir}
cd _build/src/github.com/terraform-providers/terraform-provider-openstack
go install
%endif

curr=$PWD
# extract the binary to be published
if [ -d %{_topdir}/OTHER ]; then
    cd %{buildroot}%{_bindir}
    tar zcf %{_topdir}/OTHER/%{name}-%{version}.%{_repository}.%{_arch}.tar.gz %{name}
fi
cd $curr

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}_v%{version}

%changelog
* Tue May 19 2020 dmueller@suse.com
- Update to version 1.28.0:
  * v1.28.0
  * Upgrade Terraform SDK to v1.11.0 (#1002)
  * Set Go version to 1.14.2 (#1001)
  * Add containerinfra_cluster kubeconfig attribute (#937)
  * Add blockstorage scheduler hints (#983)
  * Networking V2: cleanup subnet route resource (#999)
  * Networking: cleanup subnet V2 (#900)
  * Networking V2: cleanup secgroup resource (#1000)
  * Internal: Networking V2 Router cleanup (#712)
  * Fixed names and added volume example (#892)
  * Add Project Tags (#978)
  * Enable delayed_auth and allow_reauth options by default (#996)
  * Add SOURCE_IP_PORT load balancing method (#993)
  * Compute v2: Introduce an availability_zone_hints parameter (#985)
  * Object Storage Container V1: Add reading fields and import (#998)
  * Implemented Security Group Rule Mutex  (#994)
  * Bump gophercloud (#995)
  * Cleanup after v1.27.0 release
  * v1.27.0
  * LBaaS v2: Add batch members update resource (#898)
  * Add ACL examples (#987)
  * Update object verisoning documentation URL (#986)
  * Add support for barbican order resources (#992)
  * Image create using import web-download (#888)
  * Match type on master_addresses and node_addresses on containerinfra_cluster (#981)
  * Detach ports before deleting instance (#866)
  * Cleanup after v1.26.0 release
* Wed Mar  4 2020 Robert Schweikert <rjschwei@suse.com>
- Spec clean up
- Create required symlink
* Wed Mar  4 2020 dmueller@suse.com
- Update to version 1.26.0:
  * v1.26.0
  * Upgrade terraform-plugin-sdk to 1.7.0 (#970)
  * implement support for volume_type in block_device of openstack_compute_instance_v2 (#963)
  * Add "insert_headers" argument for lb_listener_v2 (#959)
  * Remove mitaka test job which use ubuntu-trusty (#964)
  * LBaaS: Typo fixed in lbaas l7 policy documentation (#957)
  * Key Manager V1: Introduce ACL resources for secrets and containers (#956)
* Fri Jan  3 2020 fbergmann@suse.com
- Update to version 1.25.0:
  * v1.25.0
  * Update CHANGELOG.md
  * SDK: update to terraform-plugin-sdk v1.4.1 (#936)
  * Update CHANGELOG.md
  * Add max_retries_down to lb_monitor_v2 resource (#945)
  * Update CHANGELOG.md
  * Data source for openstack_blockstorage_volume_v3 (#947)
  * Update CHANGELOG.md
  * Add resource openstack_orchestration_stack_v1 (#944)
  * Update CHANGELOG.md
  * Added support for shelved compute instance to become active (#942)
  * Update CHANGELOG.md
  * Identivy V3: add access rules support for application credentials (#920)
  * Update CHANGELOG.md
  * Update clouds.yaml doc reference to openstacksdk (#943)
  * Update CHANGELOG.md
  * Data source for openstack_blockstorage_volume_v2 (#928)
  * Docs: update COE V1 cluster fixed net and subnet (#934)
  * Internal: Decouple Authentication (#930)
  * Update CHANGELOG.md
  * Magnum - add fixed_network/fixed_subnet support (#933)
  * Update CHANGELOG.md
  * Missing character (#923)
  * Update CHANGELOG.md
  * Networking V2: Omit empty ExternalFixedIP IPAddress for the router (#628)
  * Auth: AllowReauth option should be exported (#921)
  * Update CHANGELOG.md
  * Auth: add "allow_reauth" configuration option (#918)
  * Cleanup after v1.24.0 release
  * v1.24.0
  * Update CHANGELOG.md
  * Networking V2: rename "Quotas" resource to "Quota" (#915)
  * Compute V2: add Quotaset resource (#914)
  * Update CHANGELOG.md
  * Auth: reuse existing token, when scope parameters are not defined (#913)
  * Update CHANGELOG.md
  * Core: add external client for the JSON debug (#911)
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * SDK: update to terraform-plugin-sdk v1.1.1 (#909)
  * Update CHANGELOG.md
  * Update lb_pool_v2.html.markdown (#908)
  * Update CHANGELOG.md
  * Networking V2: add Quotas resource (#907)
  * Update CHANGELOG.md
  * Fixed openstack_lb_loadbalancer_v2 flavor selection. (#904)
  * Shared filesystem V2: cleanup share access (#902)
  * Update CHANGELOG.md
  * LBaaSv2: Add UDP protocol support (#896)
  * Shared filesystem V2: cleanup securityservice (#901)
  * Update CHANGELOG.md
  * Compute V2: add "tags", "all_tags" arguments (#899)
  * Update CHANGELOG.md
  * Lbaas v2: Properly handle 404 error on status checks (#883)
  * Compute V2: Handle empty scheduler_hints lists (#885)
  * LBaaSv2: Properly handle update TLS references (#891)
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * Migrate to the new separated SDK (#880)
  * Update CHANGELOG.md
  * Check for the client error (#878)
  * Cleanup after v1.23.0 release
  * v1.23.0
  * Update CHANGELOG.md
  * LoadBalancer listener V2: fix Read method (#877)
  * Update CHANGELOG.md
  * Glance v2: Add image share resource (#872)
  * Update CHANGELOG.md
  * Identity V3: Add description support to the user and group data sources (#874)
  * Update CHANGELOG.md
  * Identity: authenticate against identity only, when it is needed (#861)
  * Update CHANGELOG.md
  * LoadBalancer V2: add timeout options for listener (#876)
  * Update CHANGELOG.md
  * Identity V3: Show domain scope info (#871)
  * Update CHANGELOG.md
  * Refactor formatting headers (#865)
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * Add ability to control caching (#849)
  * remove use of config pkg update to terraform v0.12.8
  * Update CHANGELOG.md
  * Compute V2: Read flavor's ephemeral option (#855)
  * Identity V3: Fix not found logic detection for the role assignments (#857)
  * Update CHANGELOG.md
  * Compute V2: Fix not found logic for the flavor access (#856)
  * Identity V3: Fix panic within the domain scope (#851)
  * Cleanup after v1.22.0 release
  * v1.22.0
  * Update CHANGELOG.md
  * Key manager V1: Add containers data source (#846)
  * Update CHANGELOG.md
  * Fixes #716 "Managing projects requires admin role" by using the users.ListProjects API entry point if not admin permission (#833)
  * Identity V3: fix role assignment list (#845)
  * Update CHANGELOG.md
  * LBaaS V2: Add OpenContrail monitor workaround (#840)
  * Networking V2: Mark dns attributes as computed (#837)
  * Don't fallback to 'DELETE' status, when statuses are not available (#839)
  * Update CHANGELOG.md
  * Update compute_instance_v2.html.markdown (#834)
  * Cleanup after v1.21.1 release
* Tue Sep  3 2019 tbechtold@suse.com
- Update to version 1.21.1:
  * Vendor: update Gophercloud for time format fix (#831)
  * Blockstorage V3: add quotaset resource (#828)
  * Proper handling of the empty "binding:profile" (#759)
  * Fix typo in security_groups argument (#826)
  * Identity V3: Add identity endpoint resource (#823)
  * BlockStorage V2: add Quotaset resource (#806)
  * Identity V3: Add service data source (#819)
  * Identity V3: Fix endpoint data source (#817)
  * Networking v2: Add neutron rbac policies resource (#811)
  * Key manager v1: add secret data source (#815)
  * LBaaS V2: Add flatten func for the lb pool (#725)
  * Manila V2: Allow modification of the share metadata (#825)
  * Identity V3: Add identity service resource (#821)
  * Keymanager V1: container resource (#808)
  * Keymanager V1: secrets resource (#807)
  * Check type assertion for the dns_nameservers in subnet (#726)
  * Enable import instance (#768)
  * openstack_compute_volume_attach_v3 doesn't exist (#800)
  * vpnaas_site_connection: Switch admin_state_up default to true (#799)
  * Formalize incline HCL codes to canonical format (#797)
  * Networking V2: rename QoS DSCP marking ds file (#792)
  * Networking V2: add QoS min bw datasource (#793)
  * Networking V2: add QoS min bw rule resource (#790)
  * Networking V2: add QoS dscp marking datasource (#789)
  * Networking V2: add QoS bw limit rule datasource (#788)
  * Networking V2: set QoS bw limit default direction (#791)
  * Networking V2: add QoS DSCP marking rule resource (#784)
  * Networking V2: add QoS BW limit rule resource (#783)
  * Networking V2: add QoS policy field for Port (#781)
  * Networking V2: group QoS policy imports (#782)
  * Networking V2: add QoS policy field for Network (#780)
  * Networking V2: add QoS Policy datasource (#779)
  * Networking V2: add QoS Policy resource (#774)
  * Compute v2: Fix scheduler hints query (#771)
  * Compute V2: Don't fail when disassociating floating IP from the
    instance when it is already not associated. (#761)
- terraform >= 0.12.0 is now required
* Tue Sep  3 2019 Thomas Bechtold <tbechtold@suse.com>
- Add terraform-provider-openstack-rpmlintrc as Source to .spec
* Fri Aug  9 2019 tbechtold@suse.com
- Update to version 1.19.0 (bsc#1145003):
  * Mask identity v2 auth credentials (#757)
  * Fix Debug Memory Issue (#755)
  * vendor: Updating Terraform core to v0.12-rc1 (#753)
  * DNS v2: Fix issue where TTL was being cleared (#752)
  * Acc Tests: Fix port binding syntax for v0.12 (#751)
  * Compute V2: Use Delete timeout in stop_before_destroy (#750)
  * Acc Tests: Fix allocation_pool (#749)
  * Networking v2: Make port dns_name computed (#748)
  * Internal: Networking V2 Secgroup Rule cleanup (#747)
  * Acc Tests: Add test for clearing a subnet's dns_nameservers (#746)
  * Internal: Networking V2 Router Route cleanup (#680)
  * Networking V2: add AddressScope datasource (#741)
  * vendor: update gophercloud/* (#745)
  * Networking v2: Deprecate subnet allocation_pools for allocation_pool (#739)
  * Support acceptance test against OpenStack Stein release in OpenLab (#740)
  * SharedFilesystem v2: Fix access validation rules (#738)
  * Remove fixed_ip_v6 from the network block (#737)
  * Internal: Cleanup database resources (#671)
  * Correction for the master flavour (#730)
  * SharedFilesystem v2: Add cephx and access_key (#715)
  * Networking V2: Allow floatingip associate with the fixed_ip (#709)
  * Networking V2: Add DNS support for the port, floating IP, network (#706)
  * Networking V2: Add network MTU attribute support (#708)
  * Networking V2: Introduce port binding support (#693)
  * add multi-vm with corresponding floating ip example (#710)
  * Networking V2: Add trunk data source (#626)
  * Add `prefix_length` to subnet create (#705)
  * Internal: Use ErrDefault409  (#713)
  * Networking V2: Handle multiple dhcp options in port data source (#695)
  * Networking v2: Fix security group acceptance test (#711)
  * Networking v2: Adding port_security_enabled to port resource (#682)
  * Docs: Fix incorrect floating IP reference (#703)
  * Networking v2: Network Port Security (#681)
  * Acc Tests: Fixing test fixtures (#700)
  * Debug: Allow JSON array unmarshalling in debug mode (#701)
  * Networking V2: Update port DHCP options in one API call (#689)
  * LBaaS V2: Detect null LB statuses result (#691)
  * Acc Tests: Fixes for v0.12 (#692)
  * Add blockstorage and sharefilesystem availabilityzones data sources (#652)
  * Identity V3: Add application credential resource (#660)
  * Networking v2: Revert validation of fixed_ip ip_address (#678)
  * vendor: github.com/hashicorp/terraform@ee1f8f9
  * vendor: github.com/gophercloud/utils@latest
  * vendor: github.com/gophercloud/gophercloud@latest
  * Add new data source 'openstack_compute_availability_zones_v2' (#655)
  * Remove govendor references
  * Pin go version to 1.11.5
  * Switch to go modules
  * Networking v2: Deprecate openstack_networking_subnet_v2.host_routes (#668)
  * Internal: fwaas resources cleanup (#667)
  * Internal: openstack_compute_floatingip_associate_v2 cleanup (#670)
  * Docs: Add section on Instances and Networks (#669)
  * Cleanup after v1.15.1 release
  * Networking v2: Fix Allowed Address Pairs validation (#661)
  * Compute v2: Retry multiattach volume attachments (#540)
  * Block Storage v2: Fix volume detachment 404s (#641)
  * Networking V2: Don't conflict with the tags, being set ad-hoc (#623)
  * Network V2: Fix port data source all_fixed_ips attribute (#649)
  * Provider: Terraform v0.12 TypeMap Fixes (#560)
  * Manila: recreate share and its access resources, when the region is changed (#654)
  * Auth: introduce application credential auth method (#642)
  * Compute V2: Don't fail on delete, when compute instance doesn't exist (#647)
  * Networking v2: Fix 409 bug with network refresh (#644)
  * Networking: add port secgroup associate resource (#574)
  * Internal: identity user cleanup (#614)
  * Networking V2: add Address-scope resource (#634)
  * Compute/Block Storage: Fix issue with volume detachment (#640)
  * DNS v2: Fix recordset diffs (#636)
  * Internal: Networking V2 Subnetpool cleanup (#633)
  * Internal: Networking V2 Trunk resource cleanup (#632)
  * Vet: fix unkeyed fields for importers (#635)
  * Internal: identity roles cleanup (#613)
  * Internal: identity auth scope cleanup (#609)
  * Networking V2: Add tags into the data sources (#624)
  * Internal: fix schema set for the image resource (#617)
  * Networking V2: add description to the trunk resource (#625)
  * Networking V2: Fix port data sources (#631)
  * Networking v2: Fix boolean fields of network resource (#593)
  * Internal: identity endpoint cleanup (#610)
  * Internal: identity group cleanup (#611)
  * Internal: identity project cleanup (#612)
  * Networking V2: fix fip disassociating on description update (#606)
  * Internal: fix schema set for the subnetpool data source (#616)
  * Internal: fix schema set for the subnetpool resource (#619)
  * Internal: fix schema set for the image data source (#615)
  * Internal: cleanup Networking V2 Ports (#584)
  * Internal: Networking V2 Router interface cleanup (#595)
  * Fix links and go version requirement (#607)
  * LBaaSv2: add CheckDeleted into the Delete functions (#599)
  * Manila: fix doc captions (#603)
  * Compute v2: add flavor_id to flavor data source (#587)
  * Manila: add CheckDeleted into the Delete functions (#600)
  * Compute v2: Fix Instance NIC indexing (#539)
  * Manila: introduce manila messages for detailed share errors (#596)
  * Internal: Networks cleanup (#578)
  * Update networking_port_v2.html.markdown
  * Manila: add share snapshot data source (#577)
  * Internal: Floating IP cleanup (#571)
  * Internal: block storage snapshots cleanup (#585)
  * Internal: Add ID to CheckDeleted (#592)
  * Networking v2: Fix Port admin_state_up behavior (#594)
  * Object storage: fix etag tests race condition (#590)
  * Manila: fix pending state for deleted share (#583)
  * Manila: fix pending state for deleted share ACL (#581)
  * Networking: add port ids data source (#569)
  * Manila: add share network data source (#576)
  * Internal: Floating IP associate cleanup (#572)
  * Networking: add port data source (#567)
  * Internal: DNS cleanup (#568)
  * Provider: Support Overriding Endpoints (#501)
  * provider: Require Go 1.11 in TravisCI and README (#570)
  * NetworkingV2: add transparent_vlan network datasource attribute  (#538)
  * Manila: add share data source (#564)
  * Provider: spelling and comment details (#566)
  * LBaaSv2: Prioritize loadbalancer's status in favour of subelements (#556)
  * Internal: Block Storage volumes cleanup (#544)
  * When calling API endpoints, allow a certain amount of retries (#413)
  * Manila: add share acl resource (#526)
  * NetworkingV2: add transparent_vlan network resource attribute  (#513)
  * ComputeV2: add "device_type" and "disk_bus" fields (#558)
  * ComputeV2: fix interface attach importing (#557)
  * LBaaS: Add l7rule  resource (#522)
  * LbaaS: Add l7policy resource (#527)
  * Internal: Fix expandContainerInfraV1LabelsString unit test (#555)
  * LBaaSv2: Detect individual LB object statuses, don't rely on LB status (#550)
  * Internal: Container Infra cleanup (#545)
  * LBaaSv2: Add resource import feature (#524)
  * Provider: Fix flavor detection (#551)
  * Internal: block storage volume attach cleanup (#543)
  * LBaaSv2: Improve LB objects' checks (#547)
  * fix 493 - explicitly set default bool attributes (#494)
  * LBaaSv2: bump vendor for empty "default_pool_id" update logic (#537)
  * Networking V2: add description to the floatingip data source (#523)
  * Networking V2: add description to the network data source (#536)
  * Networking V2: add description to the router data source (#530)
  * Networking V2: add description to the subnet data source (#528)
  * Networking V2: add description to the network resource (#532)
  * Networking V2: add description to the secgroup data source (#535)
  * Networking V2: add description to the floatingip resource (#534)
  * Networking V2: add description to the subnet resource (#533)
  * Networking V2: add description to the port resource (#531)
  * Networking V2: add description to the router resource (#529)
  * Manila: Shared file system securityservice and sharenetwork resources (#515)
  * Don't update resources, when there is an empty update struct (#519)
  * LBaaS: Allow LB listener default pool update without the listener re-creation (#516)
  * Reflect new gophercloud structures (#509)
  * Internal: port allowed address pairs cleanup (#505)
  * Block Storage Snapshot Data Sources (#448)
  * Allow a VM to be in a state of 'migrating' (#496)
  * ComputeV2: add soft policies (#490)
  * ContainerInfraV1: add Cluster datasource (#488)
  * Enable object versioning (#465)
  * Vendor: Updating Gophercloud (#489)
  * Internal: compute v2 servergroup cleanup (#483)
  * Internal: compute v2 volume attachment cleanup (#484)
  * Internal: compute v2 interface attach cleanup (#487)
  * Make the tenantnetworks API not required (#485)
  * Compute v2: Adding extra_specs to flavor data source (#480)
  * Compute v2: Adding fingerprint to keypair data source (#481)
  * Network v2: Rename extra_dhcp_opts to extra_dhcp_option (#486)
  * Networking V2: add DHCP opts to the port resource (#258)
  * Internal: small fixes from previous cleanup (#482)
  * Internal: compute v2 secgroup cleanup (#478)
  * Internal: compute v2 keypair cleanup (#476)
  * Internal: compute v2 flavor cleanup (#472)
  * Compute v2: openstack_compute_interface_attach (#470)
  * Internal: compute v2 floatingip cleanup
  * Fix OpenStack single volume attach example
  * Networking v2: Enable trunk tests
  * Add tags support for Neutron routers
  * Add tags support for Neutron floatingips
  * Add tags support for Neutron security groups
  * Add tags support for Neutron ports
  * Add tags support for Neutron subnetpools
  * Add tags support for Neutron subnets
  * Add tags support for Neutron networks
  * Allow to specify flavor access for tenants (#447)
  * Network resource - Trunk
  * Identity v3: Acceptance test fixes
  * vendor: Updating gophercloud/gophercloud
  * LBaaS v2: Allow member weights of 0
  * vendor: Updating Gophercloud for LBaaS v2 member weights
  * Compute v2: Enable Multiattach Volumes (#442)
  * expected_codes argument description typo (#445)
  * DNSv2: Format IPv6 Records (#443)
  * Acc Tests: Updating LBaaS v2 Member test (#441)
  * Updated deprecated resources. (#440)
  * Networking v2: Security Group Rule Fix (#438)
  * vendor: Updating gophercloud/utils (#436)
  * Enable multiattach functionality (#431)
  * Networking v2: Add no_fixed_ip to openstack_networking_port_v2 (#433)
  * Handle rackspace server addresses without type (#426)
  * Support acceptance test against OpenStack Rocky release in OpenLab (#425)
  * Compute v2: Allow power_state of error (#428)
  * ContainerInfra V1: add Cluster resource (#421)
  * ComputeV2: add instance vendor_options (#422)
  * Add description field to openstack_networking_secgroup_rule_v2 (#416)
  * ContainerInfraV1: add Cluster template datasource (#415)
  * Replace deprecated external_gateway
- Adapt _service file
- Bump required terraform version to 0.11
- Bump required go version to 1.11
* Sun Sep  9 2018 Johannes Kastl <kastl@b1-systems.de>
- first version
